GitPubEntry class

GitPubEntry is a subtype of PubEntry for git packages. It returns a SRC_URI and checksum line suitable for git repositories.

Inheritance

Constructors

GitPubEntry({required String name, required String dependency, required PubDesc? description, required String version})
GitPubEntry.fromYamlMap(String name, YamlMap map)
factory

Properties

dep → String
no setterinherited
description → PubDesc?
no setterinherited
encodedHost → String?
Returns an encoded version of the host portion of the URL. (Replaces '/' with '%47' after encoding.)
no setterinherited
git → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hosted → bool
no setterinherited
name → String
no setterinherited
remote → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String?
no setteroverride
urlSha1 → String?
Returns the SHA1 hash of the URL, or null if URL is not available.
no setter
version → String
no setterinherited

Methods

checksum() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packageName() → String
resolveRemote() → Future
By default, a generic PubEntry does not fetch a resolved URL.
override
splitUri() → Map<String?, String?>
inherited
toString() → String
A string representation of this object.
inherited
uri({String? downloadPrefix}) → String
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited