PubEntry class

Base class for a pub package entry. It holds the common data and helper methods.

Implementers

Constructors

PubEntry({required String name, required String dependency, required PubDesc? description, required String source, required String version})
PubEntry.fromYamlMap(String name, YamlMap map)
Factory constructor that creates a Hosted or Git version if needed; for other sources it creates a generic PubEntry.
factory

Properties

dep → String
no setter
description → PubDesc?
no setter
encodedHost → String?
Returns an encoded version of the host portion of the URL. (Replaces '/' with '%47' after encoding.)
no setter
git → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
hosted → bool
no setter
name → String
no setter
remote → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String?
no setter
version → String
no setter

Methods

checksum() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveRemote() → Future
By default, a generic PubEntry does not fetch a resolved URL.
splitUri() → Map<String?, String?>
toString() → String
A string representation of this object.
override
uri({String? downloadPrefix}) → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited